==> iTop-3.0.3-10998.zip: web/datamodels/2.x/itop-attachments/dictionaries/nl.dict.itop-attachments.php <==
<?php
// Copyright (C) 2010-2021 Combodo SARL
//
//   This file is part of iTop.
//
//   iTop is free software; you can redistribute it and/or modify
//   it under the terms of the GNU Affero General Public License as published by
//   the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
//   iTop is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU Affero General Public License for more details.
//
//   You should have received a copy of the GNU Affero General Public License
//   along with iTop. If not, see <http://www.gnu.org/licenses/>
/**
 * @author	LinProfs <info@linprofs.com>
 * 
 * Linux & Open Source Professionals
 * http://www.linprofs.com
 * 
 * @author Jeffrey Bostoen <info@jeffreybostoen.be> (2018 - 2022)
 * @copyright   Copyright (C) 2010-2021 Combodo SARL
 * @licence	http://opensource.org/licenses/AGPL-3.0
 */
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Attachments:TabTitle_Count' => 'Bijlagen (%1$d)',
	'Attachments:EmptyTabTitle' => 'Bijlagen',
	'Attachments:FieldsetTitle' => 'Bijlagen',
	'Attachments:DeleteBtn' => 'Verwijder',
	'Attachments:History_File_Added' => 'Bijlage %1$s toegevoegd.',
	'Attachments:History_File_Removed' => 'Bijlage %1$s verwijderd.',
	'Attachments:AddAttachment' => 'Voeg bijlage toe: ',
	'Attachments:UploadNotAllowedOnThisSystem' => 'Bestanden uploaden is NIET toegestaan op dit systeem.',
	'Attachment:Max_Go' => '(Maximale bestandsgrootte: %1$s GB)',
	'Attachment:Max_Mo' => '(Maximale bestandsgrootte: %1$s MB)',
	'Attachment:Max_Ko' => '(Maximale bestandsgrootte: %1$s kB)',
	'Attachments:NoAttachment' => 'Geen bijlage. ',
	'Attachments:PreviewNotAvailable' => 'Er is geen voorbeeld beschikbaar voor dit type bijlage.',
	'Attachments:Error:FileTooLarge' => 'Het bestand is te groot om geüpload te worden: %1$s',
	'Attachments:Error:UploadedFileEmpty' => 'Het bestand is leeg en kan niet worden toegevoegd.
Mogelijk heb je een leeg bestand geüpload,
of vraag de iTop administrator om de opslagruimte van de iTop-server na te kijken',
	'Attachments:Render:Icons' => 'Toon als pictogram',
	'Attachments:Render:Table' => 'Toon als lijst',
	'UI:Attachments:DropYourFileHint' => 'Sleep bestanden in dit gebied',
));

//
// Class: Attachment
//

Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Class:Attachment' => 'Bijlage',
	'Class:Attachment+' => '',
	'Class:Attachment/Attribute:expire' => 'Vervalt',
	'Class:Attachment/Attribute:expire+' => '',
	'Class:Attachment/Attribute:temp_id' => 'Tijdelijke ID',
	'Class:Attachment/Attribute:temp_id+' => '',
	'Class:Attachment/Attribute:item_class' => 'Klasse item',
	'Class:Attachment/Attribute:item_class+' => '',
	'Class:Attachment/Attribute:item_id' => 'Item',
	'Class:Attachment/Attribute:item_id+' => '',
	'Class:Attachment/Attribute:item_org_id' => 'Organisatie item',
	'Class:Attachment/Attribute:item_org_id+' => '',
	'Class:Attachment/Attribute:contents' => 'Inhoud',
	'Class:Attachment/Attribute:contents+' => '',
));


Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Attachments:File:Thumbnail' => 'Pictogram',
	'Attachments:File:Name' => 'Bestandsnaam',
	'Attachments:File:Date' => 'Geüpload op',
	'Attachments:File:Uploader' => 'Geüpload door',
	'Attachments:File:Size' => 'Grootte',
	'Attachments:File:MimeType' => 'Type',
));
//
// Class: Attachment
//

Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Class:Attachment/Attribute:creation_date' => 'Datum creatie',
	'Class:Attachment/Attribute:creation_date+' => '',
	'Class:Attachment/Attribute:user_id' => 'ID Gebruiker',
	'Class:Attachment/Attribute:user_id+' => '',
	'Class:Attachment/Attribute:contact_id' => 'ID Contact',
	'Class:Attachment/Attribute:contact_id+' => '',
));

==> iTop-3.1.0-2-11973.zip: web/datamodels/2.x/itop-attachments/dictionaries/nl.dict.itop-attachments.php <==
<?php
// Copyright (C) 2010-2023 Combodo SARL
//
//   This file is part of iTop.
//
//   iTop is free software; you can redistribute it and/or modify
//   it under the terms of the GNU Affero General Public License as published by
//   the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
//   iTop is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU Affero General Public License for more details.
//
//   You should have received a copy of the GNU Affero General Public License
//   along with iTop. If not, see <http://www.gnu.org/licenses/>
/**
 * @author	LinProfs <info@linprofs.com>
 * 
 * Linux & Open Source Professionals
 * http://www.linprofs.com
 * 
 * @author Jeffrey Bostoen <info@jeffreybostoen.be> (2018 - 2022)
 * @copyright   Copyright (C) 2010-2023 Combodo SARL
 * @licence	http://opensource.org/licenses/AGPL-3.0
 */
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Attachments:TabTitle_Count' => 'Bijlagen (%1$d)',
	'Attachments:EmptyTabTitle' => 'Bijlagen',
	'Attachments:FieldsetTitle' => 'Bijlagen',
	'Attachments:DeleteBtn' => 'Verwijder',
	'Attachments:History_File_Added' => 'Bijlage %1$s toegevoegd.',
	'Attachments:History_File_Removed' => 'Bijlage %1$s verwijderd.',
	'Attachments:AddAttachment' => 'Voeg bijlage toe: ',
	'Attachments:UploadNotAllowedOnThisSystem' => 'Bestanden uploaden is NIET toegestaan op dit systeem.',
	'Attachment:Max_Go' => '(Maximale bestandsgrootte: %1$s GB)',
	'Attachment:Max_Mo' => '(Maximale bestandsgrootte: %1$s MB)',
	'Attachment:Max_Ko' => '(Maximale bestandsgrootte: %1$s kB)',
	'Attachments:NoAttachment' => 'Geen bijlage. ',
	'Attachments:PreviewNotAvailable' => 'Er is geen voorbeeld beschikbaar voor dit type bijlage.',
	'Attachments:Error:FileTooLarge' => 'Het bestand is te groot om geüpload te worden: %1$s',
	'Attachments:Error:UploadedFileEmpty' => 'Het bestand is leeg en kan niet worden toegevoegd.
Mogelijk heb je een leeg bestand geüpload,
of vraag de iTop administrator om de opslagruimte van de iTop-server na te kijken',
	'Attachments:Render:Icons' => 'Toon als pictogram',
	'Attachments:Render:Table' => 'Toon als lijst',
	'UI:Attachments:DropYourFileHint' => 'Sleep bestanden in dit gebied',
));

//
// Class: Attachment
//

Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Class:Attachment' => 'Bijlage',
	'Class:Attachment+' => '',
	'Class:Attachment/Attribute:expire' => 'Vervalt',
	'Class:Attachment/Attribute:expire+' => '',
	'Class:Attachment/Attribute:temp_id' => 'Tijdelijke ID',
	'Class:Attachment/Attribute:temp_id+' => '',
	'Class:Attachment/Attribute:item_class' => 'Klasse item',
	'Class:Attachment/Attribute:item_class+' => '',
	'Class:Attachment/Attribute:item_id' => 'Item',
	'Class:Attachment/Attribute:item_id+' => '',
	'Class:Attachment/Attribute:item_org_id' => 'Organisatie item',
	'Class:Attachment/Attribute:item_org_id+' => '',
	'Class:Attachment/Attribute:contents' => 'Inhoud',
	'Class:Attachment/Attribute:contents+' => '',
));


Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Attachments:File:Thumbnail' => 'Pictogram',
	'Attachments:File:Name' => 'Bestandsnaam',
	'Attachments:File:Date' => 'Geüpload op',
	'Attachments:File:Uploader' => 'Geüpload door',
	'Attachments:File:Size' => 'Grootte',
	'Attachments:File:MimeType' => 'Type',
	'Attachments:File:DownloadsCount' => 'Downloads~~',
));
//
// Class: Attachment
//

Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Class:Attachment/Attribute:creation_date' => 'Datum creatie',
	'Class:Attachment/Attribute:creation_date+' => '',
	'Class:Attachment/Attribute:user_id' => 'ID Gebruiker',
	'Class:Attachment/Attribute:user_id+' => '',
	'Class:Attachment/Attribute:contact_id' => 'ID Contact',
	'Class:Attachment/Attribute:contact_id+' => '',
));

//
// Class: TriggerOnAttachmentDownload
//

Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Class:TriggerOnAttachmentDownload' => 'Trigger (on object\'s attachment download)~~',
	'Class:TriggerOnAttachmentDownload+' => 'Trigger on object\'s attachment download of [a child class of] the given class~~',
));
